/** @class Document
 * @name core.ComPDFKitViewer
 * @extends core.EventHandler
 * @classdesc The Document class is used to load and display documents in the DocumentViewer control.
 * @memberof core
 * @description Constructs a new empty Document, representing a document with individual pages that can be displayed on screen and printed.
 * @inner
 */
class ComPDFKitViewer extends EventHandler {
  constructor() {
  }

  /**
   * @function
   * @name core.ComPDFKitViewer#getPageWidth
   * @description Get the width of a specified page in the document.
   * @param {number} pageNumber The page number to get the width of.
   * @inner
   * @return {number} The width of the page
   */
  getPageWidth(pageNumber) {

  }

  /**
   * @function
   * @name core.ComPDFKitViewer#getPageHeight
   * @description Get the height of a specified page in the document.
   * @param {number} pageNumber The page number to get the height of.
   * @inner
   * @return {number} The height of the page
   */
  getPageHeight(pageNumber) {

  }

  /**
   * @function
   * @name core.ComPDFKitViewer#download
   * @description Download the document as an ArrayBuffer.
   * @inner
   * @return {Promise.<ArrayBuffer>}
   */
  download() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#webViewerSwitchSpreadMode
   * @description Switche the display mode of the web viewer.
   * @param {0|1|2} mode Display Mode Parameter, Single Mode: 0, Two-up Mode: 1, Cover Mode: 2
   * @inner
   */
  webViewerSwitchSpreadMode(mode) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#requestFullScreenMode
   * @description Request full screen mode for the web viewer.
   * @inner
   */
  requestFullScreenMode() {}
  
  /**
   * @function
   * @name core.ComPDFKitViewer#previousPage
   * @description Display the previous page in the web viewer.
   * @inner
   */
  previousPage() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#nextPage
   * @description Display the next page in the web viewer.
   * @inner
   */
  nextPage() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#pageNumberChanged
   * @description Display the specified page in the web viewer.
   * @param {string} pageNumber The page number to display.
   * @inner
   */
  pageNumberChanged(pageNumber) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#scrollTo
   * @description Scroll the web viewer to the specified position.
   * @inner
   */
  scrollTo() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#webViewerSwitchScrollMode
   * @description Switche the scroll mode of the web viewer.
   * @param {0|1} mode Scroll Mode Parameter, Vertical Mode: 0, Horizontal Mode: 1
   * @inner
   */
  webViewerSwitchScrollMode(mode) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#search
   * @description Searche the document for the specified text.
   * @param {string} text The Searched Content.
   * @inner
   */
  search(text) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#zoomIn
   * @description Zoom in the web viewer.
   * @inner
   */
  zoomIn() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#zoomOut
   * @description Zoom out the web viewer.
   * @inner
   */
  zoomOut() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#webViewerScaleChanged
   * @description Change the scale of the web viewer.
   * @param {number} scale The scale to change to.
   * @inner
   */
  webViewerScaleChanged(scale) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#addAnnotations
   * @description Add annotations to the document.
   * @param {object} annotation The object containing the annotation to add.
   * @inner
   */
  addAnnotations(annotation) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#insertBlankPage
   * @description Insert a blank page into the document.
   * @param {number} pageIndex The index to insert the blank page at.
   * @param {number} width The width of the blank page.
   * @param {number} height The height of the blank page.
   * @inner
   */
   insertBlankPage(pageIndex, width, height) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#insertPages
   * @description Insert pages into the document.
   * @param {File} file The file to insert.
   * @param {number} pageIndexToInsert The index to insert the pages at.
   * @param {Array.<number|string>} pagesIndexToInsert The index of the pages to insert.
   * @inner
   */
  insertPages(file, pageIndexToInsert, pagesIndexToInsert) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#removePages
   * @description Remove pages from the document.
   * @param {Array.<number>} pagesIndexToDelete The index of the pages to remove.
   * @inner
   */
  removePages(pagesIndexToDelete) {}
  
  /**
   * @function
   * @name core.ComPDFKitViewer#rotatePages
   * @description Rotate pages in the document.
   * @param {Array.<number>} pagesIndexToRotate The index of the pages to rotate.
   * @param {number} rotation The rotation to apply to the pages.
   * @inner
   */
  rotatePages(pagesIndexToRotate, rotation) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#extractPages
   * @description Extract pages from the document.
   * @param {Array.<number|string>} pagesIndexToExtract The index of the pages to extract.
   * @inner
   * @return {Promise.<ArrayBuffer>} The ArrayBuffer of the extracted pages.
   */
  extractPages(pagesIndexToExtract) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#movePages
   * @description Move pages in the document.
   * @param {string} pagesIndexToMove The index of the pages to move.
   * @param {number} targetPageIndex The index to move the pages to.
   * @inner
   */
  movePages(pagesIndexToMove, targetPageIndex) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#copyPages
   * @description Copy pages in the document.
   * @param {Array.<number>} pagesIndexToCopy The index of the pages to copy.
   * @inner
   */
  copyPages(pagesIndexToCopy) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#setPassword
   * @description Set the password for the document.
   * @param {string} password The password to set.
   * @inner
   */
  setPassword(password) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#removePassword
   * @description Remove the password from the document.
   * @inner
   */
  removePassword() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#pageToWindow
   * @description Convert a point from page coordinates to window coordinates.
   * @param {object} pagePoint The point to convert.
   * @param {number} pagePoint.x The x coordinate of the point.
   * @param {number} pagePoint.y The y coordinate of the point.
   * @param {number} pageNumber The page number of the point.
   * @inner
   * @return {object} The converted point.
   */
  pageToWindow(pagePoint, pageNumber) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#windowToPage
   * @description Convert a point from window coordinates to page coordinates.
   * @param {object} windowPoint The point to convert.
   * @param {number} windowPoint.x The x coordinate of the point.
   * @param {number} windowPoint.y The y coordinate of the point.
   * @param {number} pageNumber The page number of the point.
   * @inner
   * @return {object} The converted point.
   */
  windowToPage(windowPoint, pageNumber) {}

  /**
   * @function
   * @name core.ComPDFKitViewer#getScrollViewElement
   * @description Get the scroll view element of the web viewer.
   * @inner
   * @return {HTMLElement} The scroll view element.
   */
  getScrollViewElement() {}

  /**
   * @function
   * @name core.ComPDFKitViewer#getSelectedPage
   * @description Get the selected page of the web viewer.
   * @param {object} windowCoordinates The window coordinates to convert.
   * @param {number} windowCoordinates.x The x coordinate of the point.
   * @param {number} windowCoordinates.y The y coordinate of the point.
   * @inner
   * @return {number} The selected page.
   */
  getSelectedPage() {windowCoordinates, windowCoordinates}
}
