import ComPDFKitViewer from './ComPDFKitViewer'
import EventHandler from './EventHandler'

/** @namespace
 * @name core
 * @description ComPDFKit WebViewer Instance Core namespace. The namespace containing WebViewer's core user controls, including DocumentViewer control and the Document class.
 */

const core = {
  ComPDFKitViewer,
  EventHandler
}

/** @function
 * @name UI.setLanguage
 * @description Sets the language of the WebViewer user interface.
 * @param {zh-CN | en} language The language to set the WebViewer user interface to.
 */
function setLanguage(language) {}

/**
 * Sets the current active toolbar group. Refer to <a href='https://www.compdf.com/guides/pdf-sdk/web/ui-customization#switching-feature-areas' target='_blank'>UI Customization</a> for details.
 * @method UI.setActiceToolMode
 * @param {string} groupDataElement The groups dataElement. Default values are: toolMenu-View, toolMenu-Annotation,
 * toolMenu-Form, toolMenu-Sign, toolMenu-Security, toolMenu-Compare, toolMenu-Editor
 */
function setActiceToolMode(groupDataElement) {}

/**
 * You can customize header items. Refer to <a href='https://www.compdf.com/guides/pdf-sdk/web/ui-customization#properties-and-types-of-navigation-tools' target='_blank'>UI Customization</a> for details.
 * @method UI.setHeaderItems
 * @param {function} callback Callback function to handler different operations on the header.
*/
function setHeaderItems(callback) {}

/**
 * Show navigation bar elements. Refer to <a href='https://www.compdf.com/guides/pdf-sdk/web/ui-customization#hide-show-navigation-bar-elements' target='_blank'>Hide/Show Navigation Bar Elements</a> for details.
 * @method UI.enableElements
 * @param {Array} elements An array of elements to enable.
 */
function enableElements(elements) {}

/**
 * Hide navigation bar elements. Refer to <a href='https://www.compdf.com/guides/pdf-sdk/web/ui-customization#hide-show-navigation-bar-elements' target='_blank'>Hide/Show Navigation Bar Elements</a> for details.
 * @method UI.disableElements
 * @param {Array} elements An array of elements to disable.
 */
function disableElements(elements) {}

/**
 * Load new document into the WebViewer UI.
 * @method UI.loadDocument
 * @param {string | File} url The URL of the document or File object to load.
 */
function loadDocument(url) {}

/** @namespace
 * @name UI
 * @description ComPDFKit WebViewer Instance UI namespace. The namespace containing WebViewer's user interface controls and classes.
 */
const UI = {
  setLanguage
}

export default core
